Python library for converting between annotation formats of data domains such as images and audio.

Also offers plugins for preprocessing data, for generating statistics and visualizations,
as well as incorporating predictions made via a Redis backend (e.g., using deep learning models).
